from checkov.terraform.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_check import BaseResourceCheck


class AdminPolicyDocument(BaseResourceCheck):
    def __init__(self):
        name = "Ensure IAM policies that allow full \"*-*\" administrative privileges are not created"
        id = "CKV_AWS_1"
        supported_resource = ['aws_iam_policy_document']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resource)

    def scan_resource_conf(self, conf):
        """
            validates iam policy document
            https://learn.hashicorp.com/terraform/aws/iam-policy
        :param conf: aws_kms_key configuration
        :return: <CheckResult>
        """
        key = 'statement'
        if key in conf.keys():
            if conf[key]['actions'] == ["*"] and conf[key]['resources'] == ["*"]:
                return CheckResult.FAILED
        return CheckResult.PASSED


check = AdminPolicyDocument()



import logging
from abc import ABC, abstractmethod

from checkov.terraform.checks.resource.registry import resource_registry
from checkov.terraform.models.enums import CheckResult

class BaseResourceCheck(ABC):
    id = ""
    name = ""
    categories = []

    def __init__(self, name, id, categories, supported_resources):
        self.name = name
        self.id = id
        self.categories = categories
        self.supported_resources = supported_resources
        self.logger = logging.getLogger("{}".format(self.__module__))
        resource_registry.register(self)

    def run(self, scanned_file, resource_configuration, resource_name, resource_type, skip_info):
        check_result={}
        if skip_info:
            check_result['result'] = CheckResult.SKIPPED
            check_result['suppress_comment'] = skip_info['suppress_comment']
            message = "File {}, Resource \"{}.{}\" check \"{}\" Result: {}, Suppression comment: {} ".format(
                scanned_file, resource_type,
                resource_name,
                self.name,
                check_result, check_result['suppress_comment'])
        else:
            check_result['result'] = self.scan_resource_conf(resource_configuration)
            message = "File {}, Resource \"{}.{}\" check \"{}\" Result: {} ".format(scanned_file, resource_type,
                                                                                    resource_name,
                                                                                    self.name,
                                                                                    check_result)
        self.logger.debug(message)
        return check_result

    @abstractmethod
    def scan_resource_conf(self, conf):
        raise NotImplementedError()



#!/usr/bin/env python

from tabulate import tabulate

from checkov.terraform.checks.resource.registry import resource_registry


def print_checks():
    printable_checks_list = get_checks()
    print(tabulate(printable_checks_list, headers=["id", "Resource", "Policy"], tablefmt="github", showindex=True))
    print("\n\n---\n\n")


def get_checks():
    printable_checks_list = []
    for key in resource_registry.checks.keys():
        for check in resource_registry.checks[key]:
            printable_checks_list.append([check.id, key, check.name])
    return printable_checks_list


print_checks()



from checkov.terraform.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_check import BaseResourceCheck


class S3Versioning(BaseResourceCheck):
    def __init__(self):
        name = "Ensure all data stored in the S3 bucket have versioning enabled"
        id = "CKV_AWS_21"
        supported_resources = ['aws_s3_bucket']
        categories = [CheckCategories.BACKUP_AND_RECOVERY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
            Looks for logging configuration at aws_s3_bucket:
            https://www.terraform.io/docs/providers/aws/r/s3_bucket.html
        :param conf: aws_s3_bucket configuration
        :return: <CheckResult>
        """
        if 'versioning' in conf.keys():
            versioning_block = conf['versioning'][0]
            if versioning_block['enabled'][0]:
                return CheckResult.PASSED
        return CheckResult.FAILED


scanner = S3Versioning()



from termcolor import colored
from checkov.terraform.models.enums import CheckResult
from colorama import init, Fore

init(autoreset=True)


class Record():
    check_id = ""
    check_name = ""
    check_result = None
    check_class = ""
    code_block = ""
    file_path = ""
    file_line_range = []
    resource = ""

    def __init__(self, check_id, check_name, check_result, code_block, file_path, file_line_range, resource,
                 check_class):
        self.check_id = check_id
        self.check_name = check_name
        self.check_result = check_result
        self.code_block = code_block
        self.file_path = file_path
        self.file_line_range = file_line_range
        self.resource = resource
        self.check_class = check_class

    @staticmethod
    def _code_line_string(line_num, line):
        if '#' in line:
            return "\t\t" + Fore.WHITE + str(line_num) + ' | ' + line
        else:
            return "\t\t" + Fore.WHITE + str(line_num) + ' | ' + Fore.YELLOW + line

    def __str__(self):
        status = ''
        status_color = "white"
        if self.check_result['result'] == CheckResult.PASSED:
            status = CheckResult.PASSED.name
            status_color = "green"
        elif self.check_result['result'] == CheckResult.FAILED:
            status = CheckResult.FAILED.name
            status_color = "red"
        elif self.check_result['result'] == CheckResult.SKIPPED:
            status = CheckResult.SKIPPED.name
            status_color = 'blue'
            suppress_comment = "\tSuppress comment: {}\n".format(self.check_result['suppress_comment'])

        check_message = colored("Check: \"{}\"\n".format(self.check_name), "white")
        file_details = colored(
            "\tFile: {}:{}\n\n".format(self.file_path, "-".join([str(x) for x in self.file_line_range])),
            "magenta")
        code_lines = "{}\n".format("".join(
            [self._code_line_string(line_num, line) for (line_num, line) in self.code_block]))
        status_message = colored("\t{} for resource: {}\n".format(status, self.resource), status_color)
        if self.check_result['result'] == CheckResult.FAILED:
            return check_message + status_message + file_details + code_lines

        if self.check_result['result'] == CheckResult.SKIPPED:
            return check_message + status_message + suppress_comment + file_details
        else:
            return check_message + status_message + file_details
